@@ -40,7 +40,7 @@ __author__ = "Liguo Wang"
 __copyright__ = "Copyleft"
 __credits__ = []
 __license__ = "GPL"
-__version__="1.0.9"
+__version__="1.10.0"
 __maintainer__ = "Liguo Wang"
 __email__ = "wang.liguo@mayo.edu"
 __status__ = "Development"
@@ -62,9 +62,7 @@ def main():
 	parser.add_option("-n","--ncomponent",action="store",type='int', dest="n_components", default=2, help="Number of components. default=%default" )
 	parser.add_option("-l","--label",action="store_true",default=False,dest="text_label",help="If True, sample ids will be added underneath the data point. default=%default")
 	parser.add_option("-c","--char",action="store",type='int', default=1, dest="plot_char",help="Ploting character: 1 = 'dot', 2 = 'circle'. default=%default")
-	parser.add_option("-a","--alpha",action="store",type='float', default=0.6, dest="plot_alpha",help="Opacity of dots. A value in [0,1]. default=%default")
-	parser.add_option("-s","--dotSize",action="store",type='float', default=1.5, dest="dot_size",help="Size of dot or circle. To reduce the dot/circle size, use a value of less than 1; to increase the dot/circle size, use a value greater than 1. default=%default")
-	parser.add_option("-t","--labelSize",action="store",type='float', default=0.6, dest="label_size",help="Size of the text labels. To reduce the text size, use a value of less than 1; to increase the text size, use a value greater than 1. default=%default")
+	parser.add_option("-a","--alpha",action="store",type='float', default=0.5, dest="plot_alpha",help="Opacity of dots. default=%default")
 	parser.add_option("-x","--loc",action="store",type='int', default=1, dest="legend_location",help="Location of legend panel: 1 = 'topright', 2 = 'bottomright', 3 = 'bottomleft', 4 = 'topleft'. default=%default")
 	parser.add_option("-o","--output",action="store",type='string', dest="out_file",help="The prefix of the output file.")
 	(options,args)=parser.parse_args()
@@ -139,12 +137,12 @@ def main():
 	print ('attach(d)', file=ROUT)
 	if options.plot_alpha:
 		print ('library(scales)', file=ROUT)
-		print ('plot(PC1, PC2, col = alpha(Colors, %f), pch=%d, cex=%f, main="PCA 2D map")' % (options.plot_alpha, pch[options.plot_char], options.dot_size), file=ROUT)
+		print ('plot(PC1, PC2, col = alpha(Colors, %f), pch=%d, cex=1.5, main="PCA 2D map")' % (options.plot_alpha, pch[options.plot_char]), file=ROUT)
 	else:
-		print ('plot(PC1, PC2, col = Colors, pch=%d, cex=%f, main="PCA 2D map")' % (pch[options.plot_char], options.dot_size), file=ROUT)	
+		print ('plot(PC1, PC2, col = Colors, pch=%d, cex=1.2, main="PCA 2D map")' % pch[options.plot_char], file=ROUT)	
 	
 	if options.text_label:
-		print ('text(PC1, PC2, labels=Sample_ID, col = Colors, cex=%f, pos=1)' % (options.label_size), file=ROUT)
+		print ('text(PC1, PC2, labels=Sample_ID, col = Colors, cex=0.5, pos=1)', file=ROUT)
 	
 	print ('legend("%s", legend=c(%s), col=c(%s), pch=%d,cex=1)' %  (legend_pos[options.legend_location], ','.join(['"' + str(i) + '"' for i in group_names]), ','.join(['"' + str(group_to_col[i]) + '"' for i in group_names]), pch[options.plot_char]), file=ROUT)
 	
